#######################################################################
# The PiTrol Test Program - PiTrol_test.py                            #
#######################################################################
# Description:-                                                       #
# Run this program to test that the The PiTrol is fully working!      #
# The program prints Up, Down, Left, Right, Raspberry, Pi,            #
# North, South, East or West on the *Python Shell* Window when a      #
# PushButton Switch is pressed or the JoyStick is moved               #
# It also flashes the Yellow and Green LEDs alternately              `#
#######################################################################
#!/usr/bin/env python    #allows program to be run from command line
import time              #time package allows programmable delays in the software
import RPi.GPIO as GPIO  #RPi.GPIO package allows control of GPIO by software
GPIO.setmode(GPIO.BOARD) #Sets RPi.GPIO package to number GPIO by their Raspberry Pi Connector pin number
GPIO.setwarnings(False)  #Disables GPIO Warning Messages

# Assign the GPIO the name of the JoyStick direction it controls
Up        = 16   #GPIO for Up JoyStick Switch Input
Down      = 18   #GPIO for Right JoyStick Switch Input
Left      = 22   #GPIO for Left JoyStick Switch Input
Right     = 15   #GPIO for Down JoyStick Switch Input
Raspberry = 19   #GPIO for Centre JoyStick Switch Input

# ...and make these GPIO Inputs
GPIO.setup(Up,        GPIO.IN)
GPIO.setup(Down,      GPIO.IN)
GPIO.setup(Left,      GPIO.IN)   
GPIO.setup(Right,     GPIO.IN)
GPIO.setup(Raspberry, GPIO.IN)

# Assign the GPIO the name of the PushButton Switch it controls
Pi        =  8   #GPIO for Red Pi PushButton Switch Input
North     = 13   #GPIO for Blue North PushButton Switch Input
South     =  7   #GPIO for White South PushButton Switch Input
East      = 12   #GPIO for Green East PushButton Switch Input
West      = 11   #GPIO for Yellow West PushButton Switch Input

# ...and make these GPIO Inputs
GPIO.setup(Pi,    GPIO.IN)
GPIO.setup(North, GPIO.IN)
GPIO.setup(South, GPIO.IN)
GPIO.setup(East,  GPIO.IN)
GPIO.setup(West,  GPIO.IN)

# Assign the GPIO the name of the LED it controls
YellowLED = 5
GreenLED  = 3

# ...and make these GPIO Outputs
GPIO.setup(YellowLED, GPIO.OUT)   #GPIO for Yellow LED Output
GPIO.setup(GreenLED,  GPIO.OUT)   #GPIO for Green LED Output

poll = .1    # Define Constant for PushButton 'poll' rate
delay = 1    # Define Constant for Count delay
FLASH = True # FLASH is toggled True and False to flash LEDs

# Start of The PiTrol Test Program Execution
print "Testing The PiTrol !!!"  # Printed on Raspberry Pi *Python Shell* Window
while True :
    if FLASH == True:                 # If FLASH is True...
        GPIO.output(YellowLED, True)  # Turn Yellow LED 'on'
        GPIO.output(GreenLED, False)  # Turn Green LED 'off'
        FLASH = False                 # then Toggle FLASH to False
    else:                             # else FLASH must be False, so...
        GPIO.output(YellowLED, False) # Turn Yellow LED 'off'
        GPIO.output(GreenLED, True)   # Turn Green LED 'on'
        FLASH = True                  # Toggle FLASH to True
    
    UP        = GPIO.input(Up)        # Check all Switch GPIO inputs
    DOWN      = GPIO.input(Down)
    LEFT      = GPIO.input(Left)        
    RIGHT     = GPIO.input(Right)
    RASPBERRY = GPIO.input(Raspberry)
    PI        = GPIO.input(Pi)        
    NORTH     = GPIO.input(North)
    SOUTH     = GPIO.input(South)
    EAST      = GPIO.input(East)
    WEST      = GPIO.input(West)        

    if UP        == True:             # if JoyStick is in Up direction
        print "Up"                    # Print "Up" on *Python Shell* Window
    if DOWN      == True:             # if JoyStick is in Down direction
        print "Down"                  # Print "Down" on *Python Shell* Window
    if LEFT      == True:             # etc
        print "Left"                
    if RIGHT     == True:              
        print "Right"               
    if RASPBERRY == True:               
        print "Raspberry"               
    if PI        == True:               
        print "Pi"               
    if NORTH     == True:               
        print "North"                 
    if SOUTH     == True:               
        print "South"               
    if EAST      == True:              
        print "East"               
    if WEST      == True:               
        print "West"                
    time.sleep(poll) # wait 0.1 of a second before checking all Switches again 

